=========
Lactolyse
=========

|build| |pypi_version| |pypi_pyversions| |pypi_downloads| |code_style|

.. |build| image:: https://travis-ci.org/dblenkus/lactolyse.svg?branch=master
    :target: https://travis-ci.org/dblenkus/lactolyse
    :alt: Build Status

.. |pypi_version| image:: https://img.shields.io/pypi/v/lactolyse.svg
    :target: https://pypi.org/project/lactolyse
    :alt: Version on PyPI

.. |pypi_pyversions| image:: https://img.shields.io/pypi/pyversions/lactolyse.svg
    :target: https://pypi.org/project/lactolyse
    :alt: Supported Python versions

.. |pypi_downloads| image:: https://pepy.tech/badge/lactolyse
    :target: https://pepy.tech/project/lactolyse
    :alt: Number of downloads from PyPI

.. |code_style| image:: https://img.shields.io/badge/code%20style-black-black.svg
    :target: https://black.readthedocs.io/
    :alt: Code style: black
